searchNodes=[{"ref":"FluxMQTT.html","title":"FluxMQTT","type":"module","doc":"An interface to connect to MQTT broker, sending and handling messages."},{"ref":"FluxMQTT.html#connection/2","title":"FluxMQTT.connection/2","type":"function","doc":"Define a tuple with {Tortoise.Connection, specification} to be used as a child definition to the service supervision tree. Parameters handler - A module which uses FluxMQTT.Handler (or Tortoise.Handler) responsible to handle messages received. Accepts module/0. opts - A keyword list with connection settings. Definition is the same as application configuration and the opts defined here are merged with the application configuration. Can be blank. Accepts keyword/0. Examples iex&gt; result = FluxMQTT.connection(Tortoise.Handler.Logger) ...&gt; with {Tortoise.Connection, _specification} &lt;- result, do: :passed :passed"},{"ref":"FluxMQTT.html#send/4","title":"FluxMQTT.send/4","type":"function","doc":"Send a message to the broker using the active MQTT service on the service supersivion tree. Parameters payload - The message. Accepts String.t/0. topic - The MQTT topic which the message will be sent. Accepts String.t/0. client_id - The sender client id. Accepts String.t/0. opts - The Tortoise.publish/4 options. Accepts keyword/0. Examples iex&gt; opts = [ ...&gt; client: [ ...&gt; auth: [authenticate?: false], ...&gt; correlation: [create_correlation_id?: false] ...&gt; ] ...&gt; ] ...&gt; {connection, specification} = FluxMQTT.connection(Tortoise.Handler.Logger, opts) ...&gt; connection.start_link(specification) ...&gt; FluxMQTT.send(&quot;Hello, World!&quot;, &quot;a/topic&quot;, &quot;client&quot;) :ok"},{"ref":"FluxMQTT.Handler.html","title":"FluxMQTT.Handler","type":"behaviour","doc":"Module responsible for MQTT messages handling. The main approach to handle is done by defining a module which extends FluxMQTT.Handler and implements handle/3 function: defmodule MyApp.MQTT.Handler do use FluxMQTT.Handler @impl FluxMQTT.Handler def handle(topic, payload, state) do # Handle message end end Then, set the connection on the supervision tree: defmodule MyApp.MQTT.Supervisor do use Supervisor alias MyApp.MQTT.Handler def start_link(arg), do: Supervisor.start_link(__MODULE__, arg, name: __MODULE__) @impl Supervisor def init(_arg) do children = [ FluxMQTT.connection(Handler) ] opts = [strategy: :one_for_one] Supervisor.init(children, opts) end end Application: defmodule MyApp.Application do use Application @impl Application def start(_type, _args) do children = [ MyApp.MQTT.Supervisor ] opts = [strategy: :one_for_one] Supervisor.start_link(children, opts) end end Matching Dynamic Topics Sometimes the definition of topics cannot be determined programatically, such as when using environment variables to set the service topics. When a module uses FluxMQTT.Handler, the function match_topic/3 is imported to the module. This function expects as parameters: received - The topic received on handle/3 function. Accepts a list/0 of String.t/0. expected - The topic defined dynamically. Accepts String.t/0. matcher - Used to define the key names for the resultant map. Accepts String.t/0. Example: defmodule MyApp.MQTT.Handler do use FluxMQTT.Handler @impl FluxMQTT.Handler def handle(topic, payload, state) do expected = &quot;user/+/friend/+&quot; matcher = &quot;user/id/friend/friend_id&quot; case match_topic(topic, expected, matcher) do {:ok, %{id: id, friend_id: friend_id}} -&gt; # Use ids {:error, :unmatch} -&gt; # Not the expected topic end end end"},{"ref":"FluxMQTT.Handler.html#c:handle/3","title":"FluxMQTT.Handler.handle/3","type":"callback","doc":""},{"ref":"changelog.html","title":"Changelog","type":"extras","doc":"Changelog"},{"ref":"changelog.html#0-0-3-2019-09-03","title":"Changelog - 0.0.3 - 2019-09-03","type":"extras","doc":"Changed Callback FluxMQTT.Handler.handle/3 return type changed from atom/0 to any/0."},{"ref":"changelog.html#0-0-2-2019-09-01","title":"Changelog - 0.0.2 - 2019-09-01","type":"extras","doc":"Changed Every logger now uses metadata to describe information. There are three metadata keys that can be filtered on logger settings: :flux_mqtt_params - The params received by function. :flux_mqtt_result - The result of the function. :error - The error result of the function."},{"ref":"changelog.html#0-0-1-2019-08-31","title":"Changelog - 0.0.1 - 2019-08-31","type":"extras","doc":"Added The project is available on GitLab and Hex. Notes Minor changes (0.0.x) from the current version will be logged to this file. When a major change is released (0.x.0 or x.0.0), the changelog of the previous major change will be grouped as a single change."},{"ref":"readme.html","title":"Flux MQTT","type":"extras","doc":"Flux MQTT An interface to connect to MQTT broker, sending and handling messages. It uses Tortoise, check their documentation to understand how this library perform the configuration, handling, and delivery of MQTT messages."},{"ref":"readme.html#usage","title":"Flux MQTT - Usage","type":"extras","doc":"Add Flux MQTT as a dependency in your mix.exs file: def deps do [{:flux_mqtt, &quot;~&gt; 0.0.3&quot;}] end FluxMQTT describes how to define a connection specification and how to send a message. FluxMQTT.Handler describes how to handle MQTT messages defined in a connection."},{"ref":"readme.html#application-configuration","title":"Flux MQTT - Application Configuration","type":"extras","doc":"import Config # Default values config :flux_mqtt, broker: [ host: &quot;emq&quot;, port: 1883 ], client: [ name: &quot;client&quot;, auth: [ authenticate?: true, username: &quot;client&quot;, password: &quot;password&quot; ], correlation: [ create_correlation_id?: true, base: 36, length: 8, as: :suffix, separator: &quot;_&quot; ] ], initial_state: [], topics: [] Configuration Options :broker - Set the MQTT broker. Accepts keyword/0. Options are: :host - The MQTT broker hostname. Defaults to emq. Accepts String.t/0. :port - The MQTT broker port. Defaults to 1883. Accepts integer/0. :client - Set the service settings as a broker client. Accepts keyword/0. Options are: :name - The name of the client. Defaults to client. It is suggested to set the name as the name of the service. Accepts String.t/0. :auth - Set broker authentication settings. Accepts keyword/0. Options are: :authenticate? - If true, define the connection specification with username and password (see below). Defaults to true. Accepts boolean/0. :username - The username to be used as service authentication. Defaults to client. Accepts String.t/0. :password - The username&#39;s password. Defaults to password. Accepts String.t/0. :correlation - Set the client correlation settings. Accepts keyword/0. Options are: :create_correlation_id? - If true, the service client_id will be defined with client.name and a correlation string. Defaults to true. Accepts boolean/0. :base - The base to be used when generating a correlation id. Must have a value in the range 2..36. Defaults to 36. Accepts integer/0. :length - How many characters will be defined for the correlation id. Defaults to 8. Accepts integer/0. :as - :suffix sets the correlation id before the client name. :prefix sets the correlation id after the client name. Defaults to :suffix. Accepts :suffix or :prefix. :separator - The separator between the correlation id and the client name. Defaults to _. Accepts String.t/0. :initial_state - A keyword list with data to be set as the handler initial state. Defaults to an empty list. Accepts keyword/0. :topics - A list of {topic, qos} elements from which the handler will receive messages. Defaults to an empty list. Check Tortoise.qos/0 and Tortoise.topic/0 for more information. Accepts a list/0 of tuple/0."}]